import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = [
  'https://gist.githubusercontent.com/Saahithi49/7c606594fd7edf49f5440b780f51f84b/raw/3251abdc1cad4cae52b30966e49544b407805a6b/bmi.csv', //Dataset
].join('');

// Data gets splits, using parsing
const parseRow = (d) => {
  d.Height = +d.Height;
  d.Weight = +d.Weight;
  d.Index = +d.Index;
  d.Age = +d.Age;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// values to be viewed on X-labels
const xValue = (d) => d.Height;
const yValue = (d) => d.Weight;
const rxValue = (d) => d.Index;
const ryValue = (d) => d.Age;
const speciesValue = (d) => d.Gender;
const colorValue = d => d.Gender;
const colorLabel = 'Gender';

//Adding the legends
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Height);
  const y = yValue((d) => d.Weight);
  const marker = (d) => {
        	switch(d){
            case 'Male':
              return 'purple';
            case 'Female':
              return 'pink';
            default:
              return 'red';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.Height),
          y: yValue((d) => d.Weight),
          species: speciesValue(d),
          color: marker(speciesValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Height)
    .yValue((d) => d.Weight)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);


//Declaring the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
   'Height',
   'Weight',
   'Index',
   'Age',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'Height',
    'Weight',
    'BMI',
    'Age'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("ICE-7 BMI Reusable Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Male").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Female").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Default").style("font-size", "20px").attr("alignment-baseline","middle")
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Weight"); 
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "purple")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "pink")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")
   // plot Height on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Height");
     // plot Age on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Age");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Index");
     // plot Weight on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Weight");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();




